@@ -48,7 +48,7 @@ void FailPage::initializePage()
     QPushButton *reset = new QPushButton(this);
     KGuiItem::assign(reset, KStandardGuiItem::reset());
     reset->setText(i18nc("Button offered when the wizard fail. This button will restart the wizard", "Restart the wizard"));
-    connect(reset, &QPushButton::clicked, m_wizard, &BlueWizard::restartWizard);
+    connect(reset, &QPushButton::clicked, m_wizard, &QWizard::restart);
 
     m_wizard->setButton(QWizard::CustomButton3, reset);
     m_wizard->setButtonText(QWizard::CancelButton, i18nc("Button that closes the wizard", "Close"));
@@ -63,7 +63,7 @@ void FailPage::initializePage()
     BluezQt::DevicePtr device = m_wizard->device();
 
     if (device->name().isEmpty()) {
-        failLbl->setText(i18nc("This string is shown when the wizard fail","The setup of the device has failed"));
+        failLbl->setText(i18nc("This string is shown when the wizard fail", "The setup of the device has failed"));
     } else {
         failLbl->setText(i18n("The setup of %1 has failed", device->name()));
     }
